==> musamusa_fal-0.0.3-py3-none-any.whl: musamusa_fal/aboutproject.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
################################################################################
#    MusaMusa-Fal Copyright (C) 2021 suizokukan
#    Contact: suizokukan _A.T._ orange dot fr
#
#    This file is part of MusaMusa-Fal.
#    MusaMusa-Fal is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    MusaMusa-Fal is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with MusaMusa-Fal.  If not, see <http://www.gnu.org/licenses/>.
################################################################################
"""
   MusaMusa-Fal project : musamusa/aboutproject.py

   Global constants defining the project : version number, author, ...

   ____________________________________________________________________________


   o __author__      : (str) project's initial author
   o __email__       : (str) project's official email
   o __license__     : (str) project's license
   o __location__    : (str) project's official site
   o __projectname__ : (str) Official project's name
   o __version__     : (str) project's version
                       To propagate the project's version across all the
                       project, see the propagate_versionnumber.py script.
"""

__author__ = "Xavier Faure (suizokukan)"
__email__ = "suizokukan@orange.fr"
__license__ = "GPL-3.0"
__location__ = "github.com/suizokukan/musamusa-fal"
__projectname__ = "MusaMusa-Fal"
__version__ = "0.0.3"

==> musamusa_fal-0.0.4-py3-none-any.whl: musamusa_fal/aboutproject.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
################################################################################
#    MusaMusa-Fal Copyright (C) 2021 suizokukan
#    Contact: suizokukan _A.T._ orange dot fr
#
#    This file is part of MusaMusa-Fal.
#    MusaMusa-Fal is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    MusaMusa-Fal is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with MusaMusa-Fal.  If not, see <http://www.gnu.org/licenses/>.
################################################################################
"""
   MusaMusa-Fal project : musamusa_fal/aboutproject.py

   Global constants defining the project : version number, author, ...

   ____________________________________________________________________________


   o __author__      : (str) project's initial author
   o __email__       : (str) project's official email
   o __license__     : (str) project's license
   o __location__    : (str) project's official site
   o __projectname__ : (str) Official project's name
   o __version__     : (str) project's version
                       To propagate the project's version across all the
                       project, see the propagate_versionnumber.py script.
"""

__author__ = "Xavier Faure (suizokukan)"
__email__ = "suizokukan@orange.fr"
__license__ = "GPL-3.0"
__location__ = "github.com/suizokukan/musamusa_fal"
__projectname__ = "MusaMusa-Fal"
__version__ = "0.0.4"
